==> haskell-cmdargs-0.10.20-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cmdargs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cmdargs
version:              0.10.20
visibility:           public
id:                   cmdargs-0.10.20-3vykGHDI4u11ZYJ5Aek1JG
key:                  cmdargs-0.10.20-3vykGHDI4u11ZYJ5Aek1JG
license:              BSD-3-Clause
copyright:            Neil Mitchell 2009-2018
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/cmdargs#readme
synopsis:             Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.

    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.

    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.

    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.

    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.

category:             Console
abi:                  0a9d3442e94d9daf60d879985a6cb8d6
exposed:              True
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Implicit System.Console.CmdArgs.Quote
    System.Console.CmdArgs.Text System.Console.CmdArgs.Verbosity

hidden-modules:
    Data.Generics.Any Data.Generics.Any.Prelude
    System.Console.CmdArgs.Explicit.Complete
    System.Console.CmdArgs.Explicit.ExpandArgsAt
    System.Console.CmdArgs.Explicit.Help
    System.Console.CmdArgs.Explicit.Process
    System.Console.CmdArgs.Explicit.SplitJoin
    System.Console.CmdArgs.Explicit.Type
    System.Console.CmdArgs.Implicit.Ann
    System.Console.CmdArgs.Implicit.Global
    System.Console.CmdArgs.Implicit.Local
    System.Console.CmdArgs.Implicit.Reader
    System.Console.CmdArgs.Implicit.Reform
    System.Console.CmdArgs.Implicit.Type
    System.Console.CmdArgs.Implicit.UI

import-dirs:          /usr/lib/ghc-8.8.3/site-local/cmdargs-0.10.20
library-dirs:         /usr/lib/ghc-8.8.3/site-local/cmdargs-0.10.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/cmdargs-0.10.20
hs-libraries:         HScmdargs-0.10.20-3vykGHDI4u11ZYJ5Aek1JG
depends:
    base-4.13.0.0 filepath-1.4.2.1 process-1.6.8.0
    template-haskell-2.15.0.0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html:         /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmdargs-0.10.20-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cmdargs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cmdargs
version:              0.10.20
visibility:           public
id:                   cmdargs-0.10.20-5yLBsRitu2lKoUCxdH99aC
key:                  cmdargs-0.10.20-5yLBsRitu2lKoUCxdH99aC
license:              BSD-3-Clause
copyright:            Neil Mitchell 2009-2018
maintainer:           Neil Mitchell <ndmitchell@gmail.com>
author:               Neil Mitchell <ndmitchell@gmail.com>
homepage:             https://github.com/ndmitchell/cmdargs#readme
synopsis:             Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.

    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.

    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.

    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.

    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.

category:             Console
abi:                  95c7a6837b067b23907b0fd27bfd579c
exposed:              True
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Implicit System.Console.CmdArgs.Quote
    System.Console.CmdArgs.Text System.Console.CmdArgs.Verbosity

hidden-modules:
    Data.Generics.Any Data.Generics.Any.Prelude
    System.Console.CmdArgs.Explicit.Complete
    System.Console.CmdArgs.Explicit.ExpandArgsAt
    System.Console.CmdArgs.Explicit.Help
    System.Console.CmdArgs.Explicit.Process
    System.Console.CmdArgs.Explicit.SplitJoin
    System.Console.CmdArgs.Explicit.Type
    System.Console.CmdArgs.Implicit.Ann
    System.Console.CmdArgs.Implicit.Global
    System.Console.CmdArgs.Implicit.Local
    System.Console.CmdArgs.Implicit.Reader
    System.Console.CmdArgs.Implicit.Reform
    System.Console.CmdArgs.Implicit.Type
    System.Console.CmdArgs.Implicit.UI

import-dirs:          /usr/lib/ghc-8.10.1/site-local/cmdargs-0.10.20
library-dirs:         /usr/lib/ghc-8.10.1/site-local/cmdargs-0.10.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/cmdargs-0.10.20
hs-libraries:         HScmdargs-0.10.20-5yLBsRitu2lKoUCxdH99aC
depends:
    base-4.14.0.0 filepath-1.4.2.1 process-1.6.8.2
    template-haskell-2.16.0.0 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html:         /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
